#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-FaZ8W7H2YmQ6frTiid7o1
key:                  gitit-0.16-FaZ8W7H2YmQ6frTiid7o1
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  7e2a6029470d5ec2d1a705703d33c724
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-FaZ8W7H2YmQ6frTiid7o1
depends:
    HStringTemplate-0.8.8-HEre8yx5FYtIWmbEntIdBv
    HTTP-4000.5.0-2rpnJdgvR5r6YrIx8hk6jm
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-vFmFQLvGml64UTioNorrR base-4.18.2.1
    base64-bytestring-1.2.1.0-ClOZjdDh9gTDbeG5SOZFuY
    blaze-html-0.9.2.0-3AC4Y0zpDZCFJLvQyYdeIq bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-JHVXLxFvlNgI8FyHxR8MKb
    feed-1.3.2.1-68CzqiXLuT69s8L6nw05S filepath-1.4.300.1
    filestore-0.6.5.1-F0mO2TBoFtxF63ljDQJlfh ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-BGjJ7a3Y0c33BJoM591I3D
    hoauth2-2.14.0-3Hhbh9PQX4ULebGh3pICIW
    hslogger-1.3.2.0-FJ9PaCfbf0YCUzH6JnNXpK
    http-client-tls-0.3.6.4-J8T7BwUU5xFWZWyHYmFRx
    http-conduit-2.3.9.1-9nJOST6EfINDX8XI2pKXEb
    json-0.11-J8GMwjDtpLzBjhKyVu94EL mtl-2.3.1
    network-3.1.4.0-DevQmDdzfIO5CV4T8HvaFG
    network-bsd-2.8.1.0-KcmbLcvrwF64H7KRwYQ9nj
    network-uri-2.6.4.2-Fl60QAiqEKT2r3MxkSXMFG
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-73KymbHuW6iEs58fZhAZG5
    pandoc-3.6-JV2tUhdba73ApDvtSC1D3y
    pandoc-types-1.23.1.1-Lackzj3aTLA7KTCJCUqO0H parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-X9rgjqDoQv2X0ffpw3cKo
    recaptcha-0.1.0.4-3TAKfVYgo3UJmRBozwYPPW
    safe-0.3.21-2l2G5WXdkmS99PhZb7xIwC
    skylighting-0.14.4-9Yc2OC5Sh22CiiRJncNTi5
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 syb-0.7.3-HqXxhKD6jf2F37iIjPpcsV
    tagsoup-0.14.8-9MixDDUTtccXQfbSEPwJ1
    temporary-1.3-1srnU80DzzY9Jc5aotkmdm text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-D31qsUkpuE06bOkTHP8l3q
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-BOasXjYmoM70fD3fcOXUU xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-7niZvLkxZcxI78HVOY5QEB
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-1I5udv4LnO27iL9hRvTYtV
    zlib-0.7.1.0-KJOtboaWcInIg9F8dRf9sX

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

